pub struct DecimalBytePartsData { /* private fields */ }Expand description
This encoding allow compression of decimals using integer compression schemes.
Decimals can be compressed by narrowing the signed decimal value into the smallest signed value,
then integer compression if that is a value ptype, otherwise the decimal can be split into
parts.
These parts can be individually compressed.
This encoding will compress large signed decimals by removing the leading zeroes (after the sign)
an i128 decimal could be converted into a [i64, u64] with further narrowing applied to either
value.
This array encodes decimals as between 1-4 columns of primitive typed children.
The most significant part (msp) sorting the most significant decimal bits.
This array must be signed and is nullable iff the decimal is nullable.
e.g. for a decimal i128 [ 127..64 | 64..0 ] msp = 127..64 and lower_part[0] = 64..0
Implementations
Sourceimpl DecimalBytePartsData
impl DecimalBytePartsData
pub fn validate( msp: &ArrayRef, decimal_dtype: DecimalDType, dtype: &DType, len: usize, ) -> VortexResult<()>